/*
 * Copyright (c) 2019 Jerome Kasper <neon.king.fr@gmail.com>
 * Copyright (c) 2019, 2020 Tracey Emery <tracey@traceyemery.net>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* general sections */

a {
	color: #444444;
	text-decoration: none;
}
a:hover {
	color: Gold;
	text-decoration: none;
}
body {
	background-color: #ffffff;
	color: #000000;
	margin: 0;
	padding: 0;
	font-family: Arial, sans-serif;
}

.diff_minus, .diff_submodule {
	color: magenta;
}
.diff_plus, .diff_symlink, .diff_author {
	color: darkcyan;
}
.diff_chunk_header, .diff_date {
	background-color: LightSlateGray;
	color: yellow;
}
.diff_meta, .diff_executable, .diff_commit {
	color: green;
}
.diff_directory {
	color: blue;
}

.back_white {
	background-color: #ffffff;
}
.back_lightgray {
	background-color: #d8f3ef;
}

#refs_str {
	background-color: #243647;
	color: #ffffff;
	font-style: italic;
}
#dotted_line {
	clear: left;
	float: left;
	width: 100%;
	border-top: 1px dotted #444444;
}
#solid_line {
	clear: left;
	float: left;
	width: 100%;
	border-top: 1px solid #444444;
}
#header {
	overflow: auto;
	width: 100%;
	background-image: linear-gradient(to right, White, LightSlateGray);
}
#header a {
	color: #ffffff;
	font-size: 1.2em;
	text-decoration: none;
}
#header a:hover {
	color: Gold;
	font-size: 1.2em;
	text-decoration: none;
}
#site_path {
	clear: left;
	float: left;
	overflow: auto;
	width: 100%;
	background-color: #243647;
}
#site_link {
	float: left;
	width: 40%;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	color: #ffffff;
	overflow: hidden;
}
#site_link a {
	color: #ffffff;
	text-decoration: none;
}
#search {
	float: right;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#got_link {
	float: left;
	padding-bottom: 10px;
	padding-top: 10px;
}
#content {
	width: 100%;
}
#np_wrapper {
	clear: left;
	float: left;
	width: 100%;
	border-bottom: 1px dotted #444444;
	background-color: #f5fcfb;
	overflow: hidden;
}
#nav_prev {
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	overflow: visible;
}
#nav_next {
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	text-align: right;
	overflow: hidden;
}
#navs_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: #ced7e0;
}
#navs {
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
	font-size: .8em;
}
#site_owner_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#site_owner {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#description_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#description {
	float: left;
	width: 72%;
	padding-top: 5px;
	padding-bottom: 5px;
}
#repo_owner_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#repo_owner {
	float: left;
	width: 72%;
	padding-top: 5px;
	padding-bottom: 5px;
}
#last_change_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#last_change {
	float: left;
	width: 72%;
	padding-top: 5px;
	padding-bottom: 5px;
}
#cloneurl_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#cloneurl {
	float: left;
	width: 72%;
	padding-top: 5px;
	padding-bottom: 5px;
	overflow: auto;
	white-space: pre-wrap;
}
#tmpl_err {
	clear: left;
	float: left;
	padding-left: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
	white-space: pre-wrap;
}

/* headers */

#header_commit_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_commit {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_diff_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_diff {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_author_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_author {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_committer_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_committer {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_age_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_age {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_commit_msg_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_commit_msg {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
	white-space: pre-wrap;
}
#header_tree_title {
	clear: left;
	float: left;
	width: 6.5em;
	padding-left: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
}
#header_tree {
	float: left;
	width: 72%;
	padding-top: 2px;
	padding-bottom: 2px;
}

/* heads.tmpl */

#heads_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#heads_age {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	float: left;
	width: 7.5em;
	overflow: auto;
}
#heads_space {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	float: left;
	width: 8.5em;
	overflow: auto;
}
#head {
	float: left;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}

/* err.tmpl */

#err_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#err_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#err_content {
	clear: left;
	float: left;
	width: 100%;
	padding-left: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
}

/* briefs.tmpl */

#briefs_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#briefs_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#briefs_content {
	clear: left;
	float: left;
	width: 100%;
}
#briefs_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#briefs_age {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	float: left;
	width: 7.5em;
	overflow: auto;
}
#briefs_author {
	float: left;
	padding-top: 5px;
	padding-bottom: 5px;
	width: 8.5em;
	font-style: italic;
	overflow: auto;
}
#briefs_log {
	float: left;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	width: 65%;
}
/* index.tmpl */

#index_header {
	clear: left;
	float: left;
	overflow: auto;
	width: 100%;
	background-color: Khaki;
}
#index_header_project {
	clear: left;
	float: left;
	width: 20%;
	padding: 10px;
}
#index_header_description {
	float: left;
	width: 30%;
	padding: 10px;
}
#index_header_owner {
	float: left;
	width: 12%;
	padding: 10px;
}
#index_header_age {
	padding: 10px;
	overflow: hidden;
}
#index_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#index_project {
	float: left;
	width: 20%;
	padding: 10px;
	overflow: hidden;
}
#index_project_description {
	float: left;
	width: 30%;
	padding: 10px;
	overflow: auto;
}
#index_project_owner {
	float: left;
	width: 12%;
	padding: 10px;
	overflow: hidden;
}
#index_project_age {
	float: left;
	width: 14%;
	padding: 10px;
	overflow: visible;
}
#index_project a {
	color: #444444;
	text-decoration: none;
}
#index_project a:hover {
	color: SteelBlue;
	text-decoration: none;
}
#index_project_navs a {
	color: #444444;
	text-decoration: none;
}
#index_project_navs a:hover {
	color: SteelBlue;
	text-decoration: none;
}
#index_next a {
	color: #444444;
	text-decoration: none;
}
#index_next a:hover {
	color: SteelBlue;
	text-decoration: none;
}
#index_prev a {
	color: #444444;
	text-decoration: none;
}
#index_prev a:hover {
	color: SteelBlue;
	text-decoration: none;
}

/* commit.tmpl */

#commits_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#commits_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#commits_content {
	clear: left;
	float: left;
	width: 100%;
}
#commits_line_wrapper {
	clear: left;
	float: left;
	background-color: #f5fcfb;
	padding-top: 3px;
	padding-bottom: 3px;
	width: 100%;
}
#commit {
	clear: left;
	float: left;
	padding-left: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
	white-space: pre-wrap;
}

/* blame.tmpl */

#blame_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#blame_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#blame_content {
	clear: left;
	float: left;
	width: 100%;
}
#blame_header_wrapper {
	float: left;
	background-color: #f5fcfb;
	width: 100%;
}
#blame_header {
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 2px;
	width: 80%;
}
#blame {
	clear: left;
	float: left;
	margin-left: 20px;
	margin-top: 20px;
	margin-bottom: 20px;
	font-family: monospace;
	white-space: pre;
	overflow: auto;
}
#blame_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#blame_number {
	float: left;
	width: 3em;
	overflow: hidden;
}
#blame_hash {
	float: left;
	width: 6em;
	overflow: auto;
}
#blame_date {
	float: left;
	width: 7em;
	overflow: auto;
}
#blame_author {
	float: left;
	width: 6em;
	overflow: hidden;
}
#blame_code {
	float:left;
	width: 50%;
	overflow: visible;
}

/* tree.tmpl */

#tree_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#tree_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#tree_content {
	clear: left;
	float: left;
	width: 100%;
}
#tree_header_wrapper {
	clear: left;
	float: left;
	background-color: #f5fcfb;
	width: 100%;
}
#tree_header {
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 2px;
	width: 80%;
}
#tree {
	clear: left;
	float: left;
	margin-left: 20px;
	margin-top: 20px;
	margin-bottom: 20px;
	font-family: monospace;
}
#tree_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#tree_line {
	clear: left;
	float: left;
	width: 20em;
	padding: 1px;
}
#tree_line_blank {
	float: left;
	padding: 1px;
	width: 8em;
}
#tree_line_navs {
	float: left;
	text-align: right;
	padding: 1px;
	width: 8em;
}

/* tag.tmpl */

#tag_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#tag_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#tag_content {
	clear: left;
	float: left;
	width: 100%;
}
#tag_header_wrapper {
	clear: left;
	float: left;
	background-color: #f5fcfb;
	width: 100%;
}
#tag_header {
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 2px;
	width: 80%;
}
#tag_wrapper {
	clear: left;
	float: left;
	width: 100%;
}
#tag_age {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
	float: left;
	width: 7.5em;
	overflow: auto;
}
#tag {
	float: left;
	width: 8.5em;
	font-style: italic;
	padding-top: 5px;
	padding-bottom: 5px;
}
#tag_name {
	float: left;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#tag_info_date_title {
	clear: left;
	float: left;
	width: 7.5em;
}
#tag_info_date {
	float: left;
}
#tag_info_tagger_title {
	clear: left;
	float: left;
	width: 7.5em;
}
#tag_info_tagger {
	float: left;
}
#tag_info {
	clear: left;
	float: left;
	margin-top: 25px;
	white-space: pre-wrap;
}

/* tags.tmpl */
#tags_info {
	clear: left;
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}


/* diff.tmpl */

#diff_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#diff_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#diff_content {
	clear: left;
	float: left;
	width: 100%;
}
#diff_header_wrapper {
	float: left;
	background-color: #f5fcfb;
	width: 100%;
}
#diff_header {
	float: left;
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 2px;
	width: 80%;
}
#diff {
	clear: left;
	float: left;
	margin-left: 20px;
	margin-top: 20px;
	margin-bottom: 20px;
	font-family: monospace;
	white-space: pre;
}

/* summary.tmpl */

#summary_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: Khaki;
}
#summary_tags_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#summary_tags_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#summary_tags_content {
	clear: left;
	float: left;
	width: 100%;
}
#summary_heads_title_wrapper {
	clear: left;
	float: left;
	width: 100%;
	background-color: LightSlateGray;
	color: #ffffff;
}
#summary_heads_title {
	padding-left: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
#summary_heads_content {
	clear: left;
	float: left;
	width: 100%;
}
